@@ -5,7 +5,7 @@
 #'
 #' @note The \code{grid} and \code{gtable} packages are required for this
 #' function.
-#' @param p A ggplot2 scatterplot to add marginal plots to.  If \code{p} is
+#' @param p A ggplot2 scatterplot to add marginal plots to. If \code{p} is
 #' not provided, then all of \code{data}, \code{x}, and \code{y} must be
 #' provided.
 #' @param data The data.frame to use for creating the marginal plots. Optional
@@ -14,7 +14,8 @@
 #' provided and the \code{x} aesthetic is set in the main plot.
 #' @param y The name of the variable along the y axis. Optional if \code{p} is
 #' provided and the \code{y} aesthetic is set in the main plot.
-#' @param type What type of marginal plot to show. One of: [density, histogram, boxplot, violin].
+#' @param type What type of marginal plot to show. One of: [density, histogram, boxplot, violin, densigram] 
+#' (a "densigram" is when a density plot is overlaid on a histogram).
 #' @param margins Along which margins to show the plots. One of: [both, x, y].
 #' @param size Integer describing the relative size of the marginal plots
 #' compared to the main plot. A size of 5 means that the main plot is 5x wider
@@ -67,6 +68,9 @@
 #'
 #' # Using violin plot
 #' ggMarginal(p2, type = "violin")
+#' 
+#' # Using a "densigram" plot
+#' ggMarginal(p2, type = "densigram")
 #'
 #' # specifying the data directly instead of providing a plot
 #' ggMarginal(data = df, x = "x", y = "y")
@@ -99,7 +103,9 @@
 #'
 #' @seealso \href{http://daattali.com/shiny/ggExtra-ggMarginal-demo/}{Demo Shiny app}
 #' @export
-ggMarginal <- function(p, data, x, y, type = c("density", "histogram", "boxplot", "violin"),
+ggMarginal <- function(p, data, x, y, 
+                       type = c("density", "histogram",  "boxplot", "violin", 
+                                "densigram"),
                        margins = c("both", "x", "y"), size = 5,
                        ..., xparams = list(), yparams = list(),
                        groupColour = FALSE, groupFill = FALSE) {
@@ -109,14 +115,15 @@ ggMarginal <- function(p, data, x, y, type = c("density", "histogram", "boxplot"
   margins <- match.arg(margins)
 
   # Fill in param defaults and consolidate params into single list (prmL).
-  prmL <- toParamList(exPrm = list(...), xPrm = xparams, yPrm = yparams)
+  prmL <- toParamList(list(...), xparams, yparams)
+  
   # Reconcile different naming variants on "colour" param
   prmL <- reconcileColParamApply(prmL)
 
   # Create one version of the scat plot (scatP), based on values of p, data, x,
   # and y...also remove all margin around plot so that it's easier to position
   # the density plots beside the main plot
-  scatP <- reconcileScatPlot(p = p, data = data, x = x, y = y) +
+  scatP <- reconcileScatPlot(p, data, x, y) +
     ggplot2::theme(plot.margin = grid::unit(c(0, 0, .25, .25), "cm"))
 
   # Decompose scatP to grab all sorts of information from it
@@ -127,62 +134,38 @@ ggMarginal <- function(p, data, x, y, type = c("density", "histogram", "boxplot"
   labels <- scatPbuilt$plot$labels
   hasTitle <- (!is.null(labels$title) || !is.null(labels$subtitle))
   if (hasTitle) {
-    titleGrobs <- getTitleGrobs(p = p)
+    titleGrobs <- getTitleGrobs(p)
     scatP$labels$title <- NULL
     scatP$labels$subtitle <- NULL
   }
 
   # Create the margin plots by calling genFinalMargPlot
-  # In order to ensure the marginal plots line up nicely with the main plot,
-  # several things are done:
-  # - Use the same label text size as the original
-  # - Remove the margins from all plots
-  # - Make all text in marginal plots transparent
-  # - Remove all lines and colours from marginal plots
-  # - Use the same axis range as the main plot
-
-  # If margins = x or 'both' (x and y), then you have to create top plot
-  # Top plot = horizontal margin plot, which corresponds to x marg
   if (margins != "y") {
-    top <- genFinalMargPlot(
-      marg = "x", type = type, scatPbuilt = scatPbuilt, prmL = prmL,
-      groupColour = groupColour, groupFill = groupFill
-    )
+    plt <- MarginalPlot$new("x", type, scatPbuilt, prmL, groupColour, groupFill)
+    top <- plt$build()
   }
-
-  # If margins = y or 'both' (x and y), then you have to create right plot.
-  # (right plot = vertical margin plot, which corresponds to y marg)
   if (margins != "x") {
-    right <- genFinalMargPlot(
-      marg = "y", type = type, scatPbuilt = scatPbuilt, prmL = prmL,
-      groupColour = groupColour, groupFill = groupFill
-    )
+    plt <- MarginalPlot$new("y", type, scatPbuilt, prmL, groupColour, groupFill)
+    right <- plt$build()
   }
 
   # Now add the marginal plots to the scatter plot
   pGrob <- ggplot2::ggplotGrob(scatP)
-
   withCallingHandlers({
     suppressMessages({
       if (margins == "both") {
-        ggxtraTmp <- addTopMargPlot(ggMargGrob = pGrob, top = top, size = size)
-        ggxtraNoTtl <- addRightMargPlot(
-          ggMargGrob = ggxtraTmp, right = right, size = size
-        )
+        ggxtraTmp <- addTopMargPlot(pGrob, top, size)
+        ggxtraNoTtl <- addRightMargPlot(ggxtraTmp, right, size)
       } else if (margins == "x") {
         ggxtraTmp <- gtable::gtable_add_padding(
-          x = pGrob, grid::unit(c(0, 0.5, 0, 0), "lines")
-        )
-        ggxtraNoTtl <- addTopMargPlot(
-          ggMargGrob = ggxtraTmp, top = top, size = size
+          pGrob, grid::unit(c(0, 0.5, 0, 0), "lines")
         )
+        ggxtraNoTtl <- addTopMargPlot(ggxtraTmp, top, size)
       } else if (margins == "y") {
         ggxtraTmp <- gtable::gtable_add_padding(
-          x = pGrob, grid::unit(c(0.5, 0, 0, 0), "lines")
-        )
-        ggxtraNoTtl <- addRightMargPlot(
-          ggMargGrob = ggxtraTmp, right = right, size = size
+          pGrob, grid::unit(c(0.5, 0, 0, 0), "lines")
         )
+        ggxtraNoTtl <- addRightMargPlot(ggxtraTmp, right, size)
       }
     })
   }, warning = function(w) {
@@ -193,14 +176,14 @@ ggMarginal <- function(p, data, x, y, type = c("density", "histogram", "boxplot"
 
   # Add the title to the resulting ggExtra plot if it exists
   if (hasTitle) {
-    ggExtraPlot <- addTitleGrobs(
-      ggxtraNoTtl = ggxtraNoTtl, titleGrobs = titleGrobs
-    )
+    ggExtraPlot <- addTitleGrobs(ggxtraNoTtl, titleGrobs)
   } else {
     ggExtraPlot <- ggxtraNoTtl
   }
+  
   # Add a class for S3 method dispatch for printing the ggExtra plot
   class(ggExtraPlot) <- c("ggExtraPlot", class(ggExtraPlot))
+  
   ggExtraPlot
 }
 
@@ -219,5 +202,13 @@ ggMarginal <- function(p, data, x, y, type = c("density", "histogram", "boxplot"
 #' @keywords internal
 print.ggExtraPlot <- function(x, newpage = grDevices::dev.interactive(), ...) {
   if (newpage) grid::grid.newpage()
-  grid::grid.draw(x)
+  if (isTRUE(getOption("rstudio.notebook.executing"))) {
+    x <- ggplot2::ggplot() +
+      ggplot2::geom_blank() +
+      ggplot2::annotation_custom(x) +
+      ggplot2::theme_void()
+    print(x)
+  } else {
+    grid::grid.draw(x)
+  }
 }
