@@ -13,16 +13,12 @@
 #' }
 #' @export
 runExample <- function() {
-  if (!requireNamespace("shinyjs", quietly = TRUE)) {
-    stop('`shinyjs` package is required for this function.\nPlease install it with `install.packages("shinyjs")`',
-         call. = FALSE)
-  }
-  
   appDir <- system.file("examples", "ggMarginal", package = "ggExtra")
   if (appDir == "") {
     stop("Could not find example directory. Try re-installing `ggExtra`.",
-         call. = FALSE)
+      call. = FALSE
+    )
   }
-  
+
   shiny::runApp(appDir, display.mode = "normal")
-}
\ No newline at end of file
+}
